pub struct Controller { /* private fields */ }Expand description
A storage controller for a storage instance.
Implementations
Sourceimpl Controllerwhere
Self: StorageController,
impl Controllerwhere
Self: StorageController,
Sourcepub async fn new(
build_info: &'static BuildInfo,
persist_location: PersistLocation,
persist_clients: Arc<PersistClientCache>,
now: NowFn,
wallclock_lag: WallclockLagFn<Timestamp>,
txns_metrics: Arc<TxnMetrics>,
read_only: bool,
metrics_registry: &MetricsRegistry,
controller_metrics: ControllerMetrics,
connection_context: ConnectionContext,
txn: &dyn StorageTxn,
storage_collections: Arc<dyn StorageCollections + Send + Sync>,
) -> Self
pub async fn new( build_info: &'static BuildInfo, persist_location: PersistLocation, persist_clients: Arc<PersistClientCache>, now: NowFn, wallclock_lag: WallclockLagFn<Timestamp>, txns_metrics: Arc<TxnMetrics>, read_only: bool, metrics_registry: &MetricsRegistry, controller_metrics: ControllerMetrics, connection_context: ConnectionContext, txn: &dyn StorageTxn, storage_collections: Arc<dyn StorageCollections + Send + Sync>, ) -> Self
Create a new storage controller from a client it should wrap.
Note that when creating a new storage controller, you must also reconcile it with the previous state.
Panics
If this function is called before prepare_initialization.